@@ -1,5 +1,3 @@
-import six
-
 from sevenbridges.meta.fields import (
     HrefField, UuidField, StringField, BooleanField, CompoundField
 )
@@ -26,18 +24,13 @@ class BillingGroup(Resource):
     balance = CompoundField(Price, read_only=True)
 
     def __str__(self):
-        return six.text_type('<BillingGroup: id={id}>'.format(id=self.id))
+        return f'<BillingGroup: id={self.id}>'
 
     def __eq__(self, other):
-        if not hasattr(other, '__class__'):
-            return False
-        if not self.__class__ == other.__class__:
+        if type(other) is not type(self):
             return False
         return self is other or self.id == other.id
 
-    def __ne__(self, other):
-        return not self.__eq__(other)
-
     @classmethod
     def query(cls, offset=None, limit=None, api=None):
         """
@@ -48,7 +41,7 @@ class BillingGroup(Resource):
         :param api: Api instance.
         """
         api = api or cls._API
-        return super(BillingGroup, cls)._query(
+        return super()._query(
             url=cls._URL['query'], offset=offset, limit=limit, fields='_all',
             api=api
         )
